Learn R Programming

halk (version 0.0.5)

assign_na_age: Simple function that returns NA values

Description

A vector of NA will be returned that is the length of x

Usage

assign_na_age(x)

Value

A vector the same length as x containing only NA values

Arguments

x

Any vector of any length