These are just simple helper functions used within other functions that check to make sure that ages and lengths are present in the data and stop the fucntion call if they are missing
check_age_data(data, age_col)check_length_data(data, size_col)
NULL. An error will be called if age/length data is missing
A data.frame
Character. The column name for the age column in data
Character. The column name for the size column in data