Simple helper function to rename size and age column names to age and length
rename_laa_cols(
data,
size_col = "length",
age_col = "age",
num_col = NULL,
goback = FALSE
)A data.frame the same as data, but with names changed
Any data.frame with some columns representing age and size
Character. The name of the column containing sizes
Character. The name of the column containing ages
Character. The name of the column containing number of individuals
Logical. Reverse names once they've already been renamed