A vector of values the same length as x, but binned to the values
according to binwidth
Arguments
x
Numeric vector of values
binwidth
Numeric vector specifying how wide the length bins should be
include_upper
Logical. Append the upper value of the bin and return
the length range as a character string (TRUE), or return the lower value as
numeric (FALSE, default)