calc_mse: Calculate mean-squared-error (MSE) and root mean-squared-error (RMSE) of
estimated ages
Description
These functions will calculate MSE and RMSE for estimated ages produced by
assign_ages. Output is specific to each level used by the
age-length key to assign ages
Usage
calc_mse(data, age_col = "age")
calc_rmse(data, age_col = "age")
Value
Numeric value for estimated ages with no levels or a data.frame with
a MSE or RMSE value for each level used to fit ages